# Version 2.00, last modified on January 16, 2013 by Ryan Ly

# file names for data
data.file.name <- "DotsData.csv"
results.file.name <- "WeberResults.csv"

# script parameters
do.outlier.trial.removal <- T

# load the fitting and outlier detection functions
source("calc_w_simple_fcns.r")

d <- read.csv(data.file.name)

library(stats)
d <- d[complete.cases(d),]  # only use complete cases {stats}

d$a.r <- d$actualRatio  # remember to use larger/smaller, i.e. r>1
d$b.r <- d$binRatio     # for the bin ratio matrix
d$y <- d$y/100  # remember to use [0,1] for y

unique.ids <- unique(d$id)
N <- length(unique.ids)

# get the unique bin ratios, sorted
unique.bRatios <- unique(d$b.r)
unique.bRatios <- sort(unique.bRatios)

# create vectors of size N with value NA (null for R)
w.ls.vec <- rep(NA, N)
percent.correct.vec <- rep(NA, N)
average.rt.vec <- rep(NA, N)
num.trials.vec <- rep(NA, N)
num.outliers.vec <- rep(NA, N)

# create a matrix of size N x numbre of unique bin ratios with approp. names
acc <- matrix(NA, nrow=N, ncol=length(unique.bRatios), 
              dimnames=list(unique.ids, unique.bRatios))

cond <- rep(1, dim(d)[1])  # create vector of 1's, one for every row in d
for (i in seq(1,N)) {
	print(unique.ids[i], max.levels=0)
	cond2 <- cond & d$id==unique.ids[i]
	d2 <- d[cond2,]  # select only rows where the id matches unique.ids[i]
	rt <- d2$rt
	num.trials.pre.jolicoeur <- length(rt)

	# remove trials where rt is a jolicouer outlier 
	if (do.outlier.trial.removal)
		good.trials <- !find.outliers.jolicoeur(rt)
	else
		good.trials <- rep(T, num.trials.pre.jolicoeur)
  
	a.r <- d2[good.trials,]$a.r
	b.r <- d2[good.trials,]$b.r
	y <- d2[good.trials,]$y
	rt <- d2[good.trials,]$rt
	num.outliers <- num.trials.pre.jolicoeur - length(rt)

	M <- make.bin.ratio.matrix(b.r, y, unique.bRatios)
	acc[i,] <- M[,4]*100  # transfer bin accuracy data to acc matrix

	ls.val <- fit.w.ls(a.r, y)
  
	if (!is.na(ls.val[1])) {
    w.ls <- coef(ls.val)[[1]]
		if (w.ls < w.max) {  # only save w if w < max (else, NA)
			w.ls.vec[i] <- w.ls  # store w
			#sigma.ls.vec[i] <- summary(ls.val)$sigma # store sigma
		}
	}
	
	percent.correct.vec[i] <- mean(y)*100
	average.rt.vec[i] <- mean(rt)
	num.trials.vec[i] <- length(y)
	if (do.outlier.trial.removal)
		num.outliers.vec[i] <- num.outliers
}

cat("\n-- writing results to file: ", results.file.name, "\n", sep="")
results <- data.frame(id=unique.ids,
                      acc,
                      w.ls=w.ls.vec,
                      percent.correct=percent.correct.vec,
                      average.rt=average.rt.vec,
                      num.trials=num.trials.vec,
                      num.outliers=num.outliers.vec,
                      check.names=FALSE)
write.table(results, file=results.file.name, sep=",", row.names=FALSE)


